@@ -420,6 +420,136 @@ fail:
    return err;
 }
 
+streamContext *import_ffmpeg_read_next_frame(AVFormatContext* formatContext,
+                                             streamContext** streams,
+                                             unsigned int numStreams)
+{
+   streamContext *sc = NULL;
+   AVPacket pkt;
+
+   if (av_read_frame(formatContext,&pkt) < 0)
+   {
+      return NULL;
+   }
+
+   // Find a stream to which this frame belongs to
+   for (int i = 0; i < numStreams; i++)
+   {
+      if (streams[i]->m_stream->index == pkt.stream_index)
+         sc = streams[i];
+   }
+
+   // Off-stream packet. Don't panic, just skip it.
+   // When not all streams are selected for import this will happen very often.
+   if (sc == NULL)
+   {
+      av_free_packet(&pkt);
+      return (streamContext*)1;
+   }
+
+   // Copy the frame to the stream context
+   memcpy(&sc->m_pkt, &pkt, sizeof(AVPacket));
+
+   sc->m_pktValid = 1;
+   sc->m_pktDataPtr = pkt.data;
+   sc->m_pktRemainingSiz = pkt.size;
+
+   return sc;
+}
+
+int import_ffmpeg_decode_frame(streamContext *sc, bool flushing)
+{
+   int      nBytesDecoded;          
+   wxUint8 *pDecode = sc->m_pktDataPtr;
+   int      nDecodeSiz = sc->m_pktRemainingSiz;
+
+   sc->m_frameValid = 0;
+
+   if (flushing)
+   {
+      // If we're flushing the decoders we don't actually have any new data to decode.
+      pDecode = NULL;
+      nDecodeSiz = 0;
+   }
+   else
+   {
+      if (!sc->m_pktValid || (sc->m_pktRemainingSiz <= 0))
+      {
+         //No more data
+         return -1;
+      }
+   }
+
+   sc->m_samplefmt = sc->m_codecCtx->sample_fmt;
+   sc->m_samplesize = av_get_bits_per_sample_fmt(sc->m_samplefmt) / 8;
+
+   unsigned int newsize = FFMAX(sc->m_pkt.size * sc->m_samplesize, AVCODEC_MAX_AUDIO_FRAME_SIZE);
+   // Reallocate the audio sample buffer if it's smaller than the frame size.
+   if (newsize > sc->m_decodedAudioSamplesSiz )
+   {
+      if (sc->m_decodedAudioSamples)
+      {
+         av_free(sc->m_decodedAudioSamples);
+      }
+
+      sc->m_decodedAudioSamples = (uint8_t *) av_malloc(newsize);
+      sc->m_decodedAudioSamplesSiz = newsize;
+
+      if (sc->m_decodedAudioSamples == NULL)
+      {
+         //Can't allocate bytes
+         return -1;
+      }
+   }
+
+
+   sc->m_decodedAudioSamplesValidSiz = sc->m_decodedAudioSamplesSiz;
+
+#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT(52, 25, 0)
+   // avcodec_decode_audio3() expects the size of the output buffer as the 3rd parameter but
+   // also returns the number of bytes it decoded in the same parameter.
+   AVPacket avpkt;
+   av_init_packet(&avpkt);
+   avpkt.data = pDecode;
+   avpkt.size = nDecodeSiz;
+   nBytesDecoded =
+      avcodec_decode_audio3(sc->m_codecCtx,
+                            (int16_t *)sc->m_decodedAudioSamples,    // out
+                            &sc->m_decodedAudioSamplesValidSiz,      // in/out
+                            &avpkt);                                 // in
+#else
+   // avcodec_decode_audio2() expects the size of the output buffer as the 3rd parameter but
+   // also returns the number of bytes it decoded in the same parameter.
+   nBytesDecoded =
+      avcodec_decode_audio2(sc->m_codecCtx, 
+                            (int16_t *) sc->m_decodedAudioSamples,   // out
+                            &sc->m_decodedAudioSamplesValidSiz,      // in/out
+                            pDecode,                                 // in
+                            nDecodeSiz);                             // in
+#endif
+   if (nBytesDecoded < 0)
+   {
+      // Decoding failed. Don't stop.
+      return -1;
+   }
+
+   // We may not have read all of the data from this packet. If so, the user can call again.
+   // Whether or not they do depends on if m_pktRemainingSiz == 0 (they can check).
+   sc->m_pktDataPtr += nBytesDecoded;
+   sc->m_pktRemainingSiz -= nBytesDecoded;
+
+   // At this point it's normally safe to assume that we've read some samples. However, the MPEG
+   // audio decoder is broken. If this is the case then we just return with m_frameValid == 0
+   // but m_pktRemainingSiz perhaps != 0, so the user can call again.
+   if (sc->m_decodedAudioSamplesValidSiz > 0)
+   {
+      sc->m_frameValid = 1;
+   }
+   return 0;
+}
+
+
+
 /*******************************************************/
 
 class FFmpegNotFoundDialog;
@@ -644,6 +774,19 @@ bool FFmpegLibs::LoadLibs(wxWindow *parent, bool showerr)
          mLibAVFormatPath = path;
       }
    }
+   
+#if defined(__WXMAC__)
+   // If not successful, try loading it from legacy path
+   if (!mLibsLoaded && !GetLibAVFormatPath().IsEmpty()) {
+      wxFileName fn(wxT("/usr/local/lib/audacity"), GetLibAVFormatName());
+      wxString path = fn.GetFullPath();
+      wxLogMessage(wxT("Trying to load FFmpeg libraries from legacy path, '%s'."), path.c_str());
+      mLibsLoaded = InitLibs(path,showerr);
+      if (mLibsLoaded) {
+         mLibAVFormatPath = path;
+      }
+   }
+#endif
 
    // If not successful, try loading using system search paths
    if (!ValidLibsLoaded()) {
