@@ -254,8 +254,8 @@ bool Sequence::GetMinMax(sampleCount start, sampleCount len,
                          float * outMin, float * outMax) const
 {
    if (len == 0 || mBlock->GetCount() == 0) {
-      *outMin = float(0.0);
-      *outMax = float(0.0);
+      *outMin = float(0.0);   // FLT_MAX?  So it doesn't look like a spurious '0' to a caller?
+      *outMax = float(0.0);   // -FLT_MAX?  So it doesn't look like a spurious '0' to a caller?
       return true;
    }
 
@@ -1500,6 +1500,12 @@ bool Sequence::Append(samplePtr buffer, sampleFormat format,
    if (format != mSampleFormat) {
       temp = NewSamples(mMaxSamples, mSampleFormat);
       wxASSERT(temp);
+      // TODO: Make error message clearer?
+      /* i18n-hint: Error message shown when Audacity was trying to allocate
+         memory to hold audio, and didn't have enough.  'New Samples' is
+         the name of the C++ function that failed, for use by a developer,
+         and should not be translated - though you could say 
+         'in function "NewSamples()"' to be clearer.*/
       if (!temp) {
          wxMessageBox(_("Memory allocation failed -- NewSamples"));
          return false;
