@@ -665,7 +665,12 @@ int CommandManager::NewIdentifier(wxString name, wxString label, wxMenu *menu,
 #endif
 
    tmpEntry->defaultKey = tmpEntry->key;
+   // For key bindings for commands with a list, such as effects, 
+   // the name in prefs is the category name plus the effect name.
+   if( multi )
+      name= wxString::Format( wxT("%s:%s"), name.c_str(), label.c_str() );
    tmpEntry->name = name;
+
    tmpEntry->label = label;
    tmpEntry->labelPrefix = labelPrefix;
    tmpEntry->labelTop = wxMenuItem::GetLabelFromText(mCurrentMenuName);
@@ -840,6 +845,13 @@ void CommandManager::SetKeyFromName(wxString name, wxString key)
    }
 }
 
+void CommandManager::SetKeyFromIndex(int i, wxString key)
+{
+   CommandListEntry *entry = mCommandList[i];
+   entry->key = KeyStringNormalize(key);
+}
+
+
 void CommandManager::HandleMenuOpen(wxMenuEvent &evt)
 {
    // Ensure we have a menu and that it's a top-level menu.
@@ -1098,11 +1110,51 @@ void CommandManager::GetAllCommandNames(wxArrayString &names,
    unsigned int i;
 
    for(i=0; i<mCommandList.GetCount(); i++) {
-      if (includeMultis || !mCommandList[i]->multi)
+      if (!mCommandList[i]->multi)
          names.Add(mCommandList[i]->name);
+      else if( includeMultis )
+         names.Add(mCommandList[i]->name + wxT(":")/*+ mCommandList[i]->label*/);
    }
 }
 
+void CommandManager::GetAllCommandLabels(wxArrayString &names,
+                                        bool includeMultis)
+{
+   unsigned int i;
+
+   for(i=0; i<mCommandList.GetCount(); i++) {
+      if (!mCommandList[i]->multi)
+         names.Add(mCommandList[i]->label);
+      else if( includeMultis )
+         names.Add(mCommandList[i]->label);
+   }
+}
+
+void CommandManager::GetAllCommandData(
+   wxArrayString &names, wxArrayString &keys, wxArrayString &default_keys, wxArrayString &labels, wxArrayString & categories,
+   bool includeMultis)
+{
+   unsigned int i;
+
+   for(i=0; i<mCommandList.GetCount(); i++) {
+      if (!mCommandList[i]->multi)
+      {
+         names.Add(mCommandList[i]->name);
+         keys.Add(mCommandList[i]->key);
+         default_keys.Add( mCommandList[i]->defaultKey);
+         labels.Add(mCommandList[i]->label);
+         categories.Add(mCommandList[i]->labelTop);
+      }
+      else if( includeMultis )
+      {
+         names.Add(mCommandList[i]->name);
+         keys.Add(mCommandList[i]->key);
+         default_keys.Add( mCommandList[i]->defaultKey);
+         labels.Add(mCommandList[i]->label);
+         categories.Add(mCommandList[i]->labelTop);
+      }
+   }
+}
 wxString CommandManager::GetLabelFromName(wxString name)
 {
    CommandListEntry *entry = mCommandNameHash[name];
